hepstats.hypotests package
==========================

.. automodule:: hepstats.hypotests
   :members:
   :undoc-members:
   :show-inheritance:
   :inherited-members:

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   hepstats.hypotests.calculators
   hepstats.hypotests.core

Submodules
----------

.. toctree::
   :maxdepth: 4

   hepstats.hypotests.exceptions
   hepstats.hypotests.hypotests_object
   hepstats.hypotests.parameters
   hepstats.hypotests.toyutils
